# Makefile for espectro
# Last edited on 2004-09-26 20:40:25 by stolfi

PUBINC := /home/staff/stolfi/PUB/include
PUBLIB := /home/staff/stolfi/PUB/${PLATFORM}/lib
PUBBIN := /home/staff/stolfi/PUB/${PLATFORM}/bin

INC := /home/staff/stolfi/include
LIB := /home/staff/stolfi/${PLATFORM}/lib
BIN := /home/staff/stolfi/${PLATFORM}/bin

PROG := espectro
   
HFILES :=

CFILES :=

LIBS := \
  ${LIB}/libfftw3.a

SHELL := /bin/sh

.PHONY: \
  all clean \
  run run-single-scale run-single-pair

all: ${PROG} run
# all: ${PROG}
# all: clean ${HOFILES} ${OFILES} ${PROG}
  
MAINC := ${PROG}.c
MAKEFILE := ${PROG}.make

HOFILES := ${subst .h,.ho,${HFILES}}
OFILES := ${subst .c,.o,${CFILES}}

CC := gcc \
  -Wall  -Wpointer-arith -Wmissing-prototypes

CFLAGS :=   -O -g
LDFLAGS :=       
IFLAGS :=   -I. -I${INC} -I${PUBINC}

%.o: %.c
	${CC} ${CFLAGS} ${IFLAGS} $*.c
  
%.ho: %.h
	${CC} ${CFLAGS} ${IFLAGS} -o $*.ho -c -x c $*.h \
          || /bin/rm -f $*.ho
  
# Special rule for ${PROG}.o:

${PROG}.o: ${MAINC} ${HOFILES} \
              ${INC}/fftw3.h
	${CC} ${CFLAGS} ${IFLAGS} -o ${PROG}.o -c ${MAINC}
 
${PROG}: ${OFILES} ${PROG}.o ${LIBS}
	${CC} ${LDFLAGS} -o $@ ${PROG}.o ${OFILES} ${LIBS} -lm

clean:
	-/bin/rm -f *.o *.ho *.a *~ core ${PROG} 

# Dependencies for ".o" files:
  
######################################################################
# Running the program

# Number of bases in the samples of aligned homologous subsequence pairs:
NREAD := 495

# Number of base pairs to extract from each sequence pair, for multiscale:
NUSE_MS := 480

# Number of base pairs to extract from each sequence pair, for uniscale:
NUSE_US := 495

# Sampling scales (0 = original):
SCALES := 0 1 2 3 4 5
# SCALES := 0 1
# SCALES := 1

# Sigma to use on first filtering (from scale 0 to scale 1):
SGMZERO := 0.75

run: run-multiscale run-uniscale
# run: run-uniscale
 
run-multiscale: 
	for sc in ${SCALES} ; do \
          ${MAKE} -f ${MAKEFILE} \
            NUSE=${NUSE_MS} SCALE=$$sc \
            run-single-scale ; \
        done

run-uniscale: 
	${MAKE} -f ${MAKEFILE} \
          NUSE=${NUSE_US} SCALE=0 \
          run-single-scale
        
######################################################################
# Recursive make - caller must define ${SCALE}, ${NUSE}

SCALE := SCALE.IS.UNDEFINED
ifneq "${SCALE}" "SCALE.IS.UNDEFINED"
NUSE := NUSE.IS.UNDEFINED
ifneq "${NUSE}" "NUSE.IS.UNDEFINED"
        
# Names of homologous sequence pairs:
PAIRLISTFILE := ../data/pairs.txt
PAIRS := ${shell cat ${PAIRLISTFILE}}

run-single-scale: 
	sh=0; \
        for pair in ${PAIRS} ; do \
          ${MAKE} -f ${MAKEFILE} \
            PAIR=$$pair SHIFT=$$sh \
            SCALE=${SCALE} NUSE=${NUSE} \
            run-single-pair ; \
          sh=$$((sh+1)); \
        done
       
######################################################################
# Recursive make - caller must define ${PAIR}, ${SHIFT}

PAIR := PAIR.IS.UNDEFINED
ifneq "${PAIR}" "PAIR.IS.UNDEFINED"

SHIFT := SHIFT.IS.UNDEFINED
ifneq "${SHIFT}" "SHIFT.IS.UNDEFINED"
        
DATADIR := ../data
RSLTDIR := ../rslt
       
INFILE := ${DATADIR}/${PAIR}ag.txt
OTFILE := ${RSLTDIR}/s${SCALE}-${NUSE}-${PAIR}.txt

run-single-pair: ${OTFILE}

${OTFILE}: ${INFILE} ${PROG} ${MAKEFILE}
	./${PROG} \
            ${NREAD} ${NUSE} ${SGMZERO} ${SHIFT} ${SCALE} \
          < ${INFILE} \
          > ${OTFILE}

endif
endif
# End make ${PAIR}, ${SHIFT}
######################################################################

endif
endif
# End make ${SCALE}, ${NUSE}
######################################################################
